@@ -7,7 +7,7 @@
 #' See \code{\link{RoundViaDummy}} for more details.
 #'
 #' @param data Input data as a data frame (inner cells)
-#' @param freqVar Variable holding counts (inner cells frequencies)
+#' @param freqVar Variable holding counts (inner cells frequencies).  When \code{NULL} (default), microdata is assumed.
 #' @param roundBase Rounding base
 #' @param hierarchies List of hierarchies
 #' @param formula Model formula defining publishable cells
@@ -15,6 +15,7 @@
 #' @param maxRound Inner cells contributing to original publishable cells equal to or less than maxRound will be rounded
 #' @param printInc Printing iteration information to console when TRUE  
 #' @param output Possible non-NULL values are \code{"inner"} and \code{"publish"}. Then a single data frame is returned.
+#' @param preAggregate When \code{TRUE}, the data will be aggregated beforehand within the function by the dimensional variables. 
 #' @param ... Further parameters sent to \code{RoundViaDummy}  
 #'
 #' @return Output is a four-element list with class attribute "PLSrounded" (to ensure informative printing).
@@ -28,7 +29,7 @@
 #'    For example, row "\code{rounded}" and column "\code{inn.4+}" is the number of rounded 
 #'    inner cell frequencies greater than or equal to \code{4}.}
 #'    
-#' @seealso   \code{\link{RoundViaDummy}}, \code{\link{PLS2way}} 
+#' @seealso   \code{\link{RoundViaDummy}}, \code{\link{PLS2way}}, \code{\link{ModelMatrix}} 
 #' 
 #' @references 
 #' Langsrud, Ø. and Heldal, J. (2018): \dQuote{An Algorithm for Small Count Rounding of Tabular Data}. 
@@ -38,6 +39,7 @@
 #' @encoding UTF8
 #' 
 #' @importFrom SSBtools CharacterDataFrame
+#' @importFrom stats aggregate as.formula delete.response terms
 #' @export
 #'
 #' @examples
@@ -78,6 +80,16 @@
 #' # Also possible to combine hierarchies and formula
 #' PLSrounding(z, "freq", hierarchies = SmallCountData("eDimList"), formula = ~geo + year)
 #' 
+#' # Single data frame output
+#' PLSroundingInner(z, "freq", roundBase = 5, formula = ~geo + eu + year)
+#' PLSroundingPublish(z, roundBase = 5, formula = ~geo + eu + year)
+#' 
+#' # Microdata input
+#' PLSroundingInner(rbind(z, z), roundBase = 5, formula = ~geo + eu + year)
+#' 
+#' # Parameter avoidHierarchical (see RoundViaDummy and ModelMatrix) 
+#' PLSroundingPublish(z, roundBase = 5, formula = ~geo + eu + year, avoidHierarchical = TRUE)
+#' 
 #' # Package sdcHierarchies can be used to create hierarchies. 
 #' # The small example code below works if this package is available. 
 #' if (require(sdcHierarchies)) {
@@ -101,10 +113,51 @@
 #' PLS2way(a)  # Values in col1 rounded
 #' a <- PLSrounding(exPSD, "freq", 5, formula = ~rows + cols, zeroCandidates = TRUE)
 #' PLS2way(a)  # (row3, col4): original is 0 and rounded is 5
-PLSrounding <- function(data, freqVar, roundBase = 3, hierarchies = NULL, formula = NULL, 
+PLSrounding <- function(data, freqVar = NULL, roundBase = 3, hierarchies = NULL, formula = NULL, 
                         dimVar = NULL,
                         maxRound = roundBase-1, printInc = nrow(data)>1000, 
-                        output = NULL, ...) {
+                        output = NULL, 
+                        preAggregate = is.null(freqVar), ...) {
+  
+  
+  force(preAggregate)
+  
+  if (preAggregate) {
+    if (printInc) {
+      cat("[preAggregate ", dim(data)[1], "*", dim(data)[2], "->", sep = "")
+      flush.console()
+    }
+    if (!is.null(hierarchies)) {
+      dVar <- names(hierarchies)
+    } else {
+      if (!is.null(formula)) {
+        dVar <- row.names(attr(delete.response(terms(as.formula(formula))), "factors"))
+      } else {
+        if (!is.null(dimVar)){
+          dVar <- dimVar
+        } else {
+          if (is.null(freqVar)){
+            dVar <- names(data)
+          } else {
+            freqVarName <- names(data[1, freqVar, drop = FALSE])
+            dVar <- names(data[1, !(names(data) %in% freqVarName), drop = FALSE])
+          }
+        }
+      }
+    }
+    dVar <- unique(dVar)
+    if (is.null(freqVar)) {
+      data <- aggregate(list(f_Re_qVa_r = data[[dVar[1]]]), data[dVar], length)
+      freqVar <- "f_Re_qVa_r"
+    } else {
+      data <- aggregate(data[freqVar], data[dVar], sum)
+    }
+    if (printInc) {
+      cat(dim(data)[1], "*", dim(data)[2], "]\n", sep = "")
+      flush.console()
+    }
+  }
+  
   
   if(!is.null(output)){
     if(!(output %in% c("inner", "publish")))
@@ -141,7 +194,7 @@ PLSrounding <- function(data, freqVar, roundBase = 3, hierarchies = NULL, formul
   
   freqTable <- cbind(TabCat(z$yInner, roundBase, "inn.", maxRound), TabCat(z$yPublish, roundBase, "pub.", maxRound))
   
-  freqVarName <- names(data[1, freqVar, drop = FALSE])
+  # freqVarName <- names(data[1, freqVar, drop = FALSE])
   
   out <- NULL
   
