@@ -77,6 +77,38 @@ test_that("PLSrounding works", {
 })
 
 
+
+test_that("preAggregate works", {
+  printInc <- FALSE
+  
+  formula <- ~eu * year + geo * year
+  zM <- SSBtools::MakeMicro(SmallCountData("e6"), "freq")[, -4]
+  zF <- aggregate(list(freq = zM[[1]]), zM, length)
+  
+  aM <- PLSrounding(zM, formula = formula, printInc = printInc)
+  aF <- PLSrounding(zF, "freq", formula = formula, printInc = printInc)
+  
+  expect_equal(nrow(aM[[1]]), nrow(zF))
+  expect_equal(diff(range(diff(sort(SSBtools::Match(aM[[1]], aF[[1]]))))), 0)
+  expect_identical(aM[[2]], aF[[2]][names(aM[[2]])])
+  expect_identical(aM[3:4], aF[3:4])
+  
+  aM <- PLSrounding(zM, printInc = printInc)
+  expect_equal(diff(range(diff(sort(SSBtools::Match(aM[[1]], aF[[1]]))))), 0)
+  expect_equal(diff(range(diff(sort(SSBtools::Match(aM[[2]], aF[[2]]))))), 0)
+  expect_identical(aM[3:4], aF[3:4])
+  
+  aM <- PLSrounding(zM, hierarchies = SmallCountData("eDimList"), printInc = printInc)
+  expect_equal(diff(range(diff(sort(SSBtools::Match(aM[[1]], aF[[1]]))))), 0)
+  expect_equal(diff(range(diff(sort(SSBtools::Match(aM[[2]], aF[[2]]))))), 0)
+  expect_identical(aM[3:4], aF[3:4])
+  
+  aM <- PLSrounding(zM, formula = formula, printInc = printInc,  preAggregate = FALSE)
+  expect_equal(nrow(aM[[1]]), nrow(zM))
+  expect_equal(diff(range(diff(sort(SSBtools::Match(aM[[2]], aF[[2]]))))), 0)
+
+})
+
 test_that("Parameter preRounded", {
   mf2 <- ~region + hovedint + fylke * hovedint + kostragr * hovedint
   z2 <- SmallCountData("z2")
@@ -139,6 +171,7 @@ PLStest = function(..., seed, Version){
 
 
 test_that("Same as Version_0.3.0", {
+  skip_on_cran()
   seed = 123
   mf <- ~region*mnd + hovedint*mnd + fylke*hovedint*mnd + kostragr*hovedint*mnd
   PLStest(SmallCountData('z3'), 'ant', 3, formula = mf, seed= seed, Version = "0.3.0")
